@@ -5,8 +5,8 @@
 ;; Author: Damien Cassou <damien@cassou.me>
 ;; URL: https://github.com/DamienCassou/navigel
 ;; Package-Requires: ((emacs "25.1") (tablist "1.0"))
-;; Package-Version: 1.1.0
-;; Package-Revision: v1.1.0-0-g539fe2d9542b
+;; Package-Version: 20251012.1517
+;; Package-Revision: 3dc4aa6f7aeb
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -189,7 +189,7 @@ majority of cases."
 
 (cl-defgeneric navigel-bookmark-name (entity)
   "Return a string representing ENTITY for `bookmark'."
-  (format "%s: %s" navigel-app (navigel-name entity)))
+  (navigel-name entity))
 
 (cl-defgeneric navigel-children (entity callback)
   "Execute CALLBACK with the list of ENTITY's children as argument.
